/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <pysideqenum.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <iterator>

// module include
#include "pyside2_qtdatavisualization_python.h"

// main header
#include "qtdatavisualization_qsurface3dseries_wrapper.h"

// inner classes

#include <cctype>
#include <cstring>

using namespace QtDataVisualization;



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void QSurface3DSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSurface3DSeriesWrapper::QSurface3DSeriesWrapper(QObject * parent) : QtDataVisualization::QSurface3DSeries(parent)
{
    resetPyMethodCache();
    // ... middle
}

QSurface3DSeriesWrapper::QSurface3DSeriesWrapper(QtDataVisualization::QSurfaceDataProxy * dataProxy, QObject * parent) : QtDataVisualization::QSurface3DSeries(dataProxy, parent)
{
    resetPyMethodCache();
    // ... middle
}

void QSurface3DSeriesWrapper::childEvent(QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[0] = true;
        return this->::QObject::childEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
    Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QSurface3DSeriesWrapper::connectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[1] = true;
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
    Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QSurface3DSeriesWrapper::customEvent(QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[2] = true;
        return this->::QObject::customEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
    Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QSurface3DSeriesWrapper::disconnectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[3] = true;
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
    Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QSurface3DSeriesWrapper::event(QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[4] = true;
        return this->::QObject::event(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
    Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QSurface3DSeries.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QSurface3DSeriesWrapper::eventFilter(QObject * watched, QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[5] = true;
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
    Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
    Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QSurface3DSeries.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QSurface3DSeriesWrapper::timerEvent(QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[7] = true;
        return this->::QObject::timerEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
    Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject *QSurface3DSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QtDataVisualization::QSurface3DSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSurface3DSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QtDataVisualization::QSurface3DSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSurface3DSeriesWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QSurface3DSeriesWrapper *>(this));
        return QtDataVisualization::QSurface3DSeries::qt_metacast(_clname);
}

QSurface3DSeriesWrapper::~QSurface3DSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QtDataVisualization_QSurface3DSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QtDataVisualization::QSurface3DSeries >()))
        return -1;

    ::QSurface3DSeriesWrapper *cptr{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.__init__";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QSurface3DSeries", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QSurface3DSeries::QSurface3DSeries(QObject*)
    // 1: QSurface3DSeries::QSurface3DSeries(QtDataVisualization::QSurfaceDataProxy*,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSurface3DSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACEDATAPROXY_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSurface3DSeries(QtDataVisualization::QSurfaceDataProxy*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QSurface3DSeries(QtDataVisualization::QSurfaceDataProxy*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSurface3DSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QSurface3DSeries(QObject * parent)
        {
            if (kwds) {
                PyObject *value{};
                PyObject *kwds_dup = PyDict_Copy(kwds);
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent)) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value && pyArgs[0]) {
                        errInfo = key_parent;
                        Py_INCREF(errInfo);
                        goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;
                    }
                    if (value) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0]))))
                            goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo = kwds_dup;
                    // fall through to handle extra keyword signals and properties
                } else {
                    Py_DECREF(kwds_dup);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // QSurface3DSeries(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr) {
                    cptr = new (addr) ::QSurface3DSeriesWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(0);
                } else {
                    cptr = new ::QSurface3DSeriesWrapper(cppArg0);
                }

                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QSurface3DSeries(QtDataVisualization::QSurfaceDataProxy * dataProxy, QObject * parent)
        {
            if (kwds) {
                PyObject *value{};
                PyObject *kwds_dup = PyDict_Copy(kwds);
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent)) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value && pyArgs[1]) {
                        errInfo = key_parent;
                        Py_INCREF(errInfo);
                        goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;
                    }
                    if (value) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[1]))))
                            goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo = kwds_dup;
                    // fall through to handle extra keyword signals and properties
                } else {
                    Py_DECREF(kwds_dup);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QtDataVisualization::QSurfaceDataProxy *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!PyErr_Occurred()) {
                // QSurface3DSeries(QtDataVisualization::QSurfaceDataProxy*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr) {
                    cptr = new (addr) ::QSurface3DSeriesWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(0);
                } else {
                    cptr = new ::QSurface3DSeriesWrapper(cppArg0, cppArg1);
                }

                Shiboken::Object::setParent(self, pyArgs[0]);
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QtDataVisualization::QSurface3DSeries >(), cptr)) {
        delete cptr;
        Py_XDECREF(errInfo);
        return -1;
    }
    if (!cptr) goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (errInfo && PyDict_Check(errInfo)) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo))
            goto Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError;
        Py_DECREF(errInfo);
    };


    return 1;

    Sbk_QtDataVisualization_QSurface3DSeries_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, fullName, errInfo);
        Py_XDECREF(errInfo);
        return -1;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_dataProxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.dataProxy";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // dataProxy()const
            QtDataVisualization::QSurfaceDataProxy * cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->dataProxy();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACEDATAPROXY_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_drawMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.drawMode";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // drawMode()const
            QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag> cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->drawMode();
            pyResult = Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_invalidSelectionPosition(PyObject *self)
{
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.invalidSelectionPosition";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // invalidSelectionPosition()
            QPoint cppResult = ::QtDataVisualization::QSurface3DSeries::invalidSelectionPosition();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QPOINT_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_isFlatShadingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.isFlatShadingEnabled";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isFlatShadingEnabled()const
            bool cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->isFlatShadingEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_isFlatShadingSupported(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.isFlatShadingSupported";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isFlatShadingSupported()const
            bool cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->isFlatShadingSupported();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_selectedPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.selectedPoint";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // selectedPoint()const
            QPoint cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->selectedPoint();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QPOINT_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDataProxy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setDataProxy";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setDataProxy(QtDataVisualization::QSurfaceDataProxy*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACEDATAPROXY_IDX]), (pyArg)))) {
        overloadId = 0; // setDataProxy(QtDataVisualization::QSurfaceDataProxy*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDataProxy_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QtDataVisualization::QSurfaceDataProxy *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setDataProxy(QtDataVisualization::QSurfaceDataProxy*)
            cppSelf->setDataProxy(cppArg0);
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDataProxy_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDrawMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setDrawMode";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setDrawMode(QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, (pyArg)))) {
        overloadId = 0; // setDrawMode(QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDrawMode_TypeError;

    // Call function/method
    {
        ::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag> cppArg0 = QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setDrawMode(QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>)
            cppSelf->setDrawMode(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDrawMode_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_setFlatShadingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setFlatShadingEnabled";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setFlatShadingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFlatShadingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeriesFunc_setFlatShadingEnabled_TypeError;

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setFlatShadingEnabled(bool)
            cppSelf->setFlatShadingEnabled(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QtDataVisualization_QSurface3DSeriesFunc_setFlatShadingEnabled_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_setSelectedPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setSelectedPoint";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setSelectedPoint(QPoint)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QPOINT_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectedPoint(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeriesFunc_setSelectedPoint_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QPOINT_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setSelectedPoint(QPoint)
            cppSelf->setSelectedPoint(*cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QtDataVisualization_QSurface3DSeriesFunc_setSelectedPoint_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setTexture";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setTexture(QImage)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QIMAGE_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTexture_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QImage cppArg0_local;
        ::QImage *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QIMAGE_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setTexture(QImage)
            cppSelf->setTexture(*cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTexture_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTextureFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setTextureFile";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setTextureFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // setTextureFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTextureFile_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setTextureFile(QString)
            cppSelf->setTextureFile(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTextureFile_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.texture";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // texture()const
            QImage cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->texture();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QIMAGE_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtDataVisualization_QSurface3DSeriesFunc_textureFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.textureFile";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // textureFile()const
            QString cppResult = const_cast<const ::QtDataVisualization::QSurface3DSeries *>(cppSelf)->textureFile();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QtDataVisualization_QSurface3DSeries_PropertyStrings[] = {
    "dataProxy::",
    "drawMode::",
    "flatShadingEnabled:isFlatShadingEnabled:",
    "flatShadingSupported:isFlatShadingSupported",
    "selectedPoint::",
    "texture::",
    "textureFile::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtDataVisualization_QSurface3DSeries_methods[] = {
    {"dataProxy", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_dataProxy), METH_NOARGS},
    {"drawMode", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_drawMode), METH_NOARGS},
    {"invalidSelectionPosition", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_invalidSelectionPosition), METH_NOARGS|METH_STATIC},
    {"isFlatShadingEnabled", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_isFlatShadingEnabled), METH_NOARGS},
    {"isFlatShadingSupported", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_isFlatShadingSupported), METH_NOARGS},
    {"selectedPoint", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_selectedPoint), METH_NOARGS},
    {"setDataProxy", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDataProxy), METH_O},
    {"setDrawMode", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_setDrawMode), METH_O},
    {"setFlatShadingEnabled", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_setFlatShadingEnabled), METH_O},
    {"setSelectedPoint", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_setSelectedPoint), METH_O},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTexture), METH_O},
    {"setTextureFile", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_setTextureFile), METH_O},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_texture), METH_NOARGS},
    {"textureFile", reinterpret_cast<PyCFunction>(Sbk_QtDataVisualization_QSurface3DSeriesFunc_textureFile), METH_NOARGS},

    {nullptr, nullptr} // Sentinel
};

static int Sbk_QtDataVisualization_QSurface3DSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value && PyCallable_Check(value)) {
        auto plain_inst = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX], reinterpret_cast<SbkObject *>(self)));
        auto inst = dynamic_cast<QSurface3DSeriesWrapper *>(plain_inst);
        if (inst)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QtDataVisualization_QSurface3DSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QtDataVisualization_QSurface3DSeries_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QtDataVisualization_QSurface3DSeries_Type = nullptr;
static SbkObjectType *Sbk_QtDataVisualization_QSurface3DSeries_TypeF(void)
{
    return _Sbk_QtDataVisualization_QSurface3DSeries_Type;
}

static PyType_Slot Sbk_QtDataVisualization_QSurface3DSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QtDataVisualization_QSurface3DSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtDataVisualization_QSurface3DSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtDataVisualization_QSurface3DSeries_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtDataVisualization_QSurface3DSeries_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QtDataVisualization_QSurface3DSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtDataVisualization_QSurface3DSeries_spec = {
    "2:PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QtDataVisualization_QSurface3DSeries_slots
};

} //extern "C"

static void *Sbk_QtDataVisualization_QSurface3DSeries_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QtDataVisualization::QSurface3DSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}

PyObject *SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___and__(PyObject *self, PyObject *pyArg)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyLong_AsLong(pyArg)));
    if (PyErr_Occurred())
    return nullptr;
#else
    cppSelf = static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyInt_AsLong(pyArg)));
#endif

    if (PyErr_Occurred())
        return nullptr;
    cppResult = cppSelf & cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___or__(PyObject *self, PyObject *pyArg)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyLong_AsLong(pyArg)));
    if (PyErr_Occurred())
    return nullptr;
#else
    cppSelf = static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyInt_AsLong(pyArg)));
#endif

    if (PyErr_Occurred())
        return nullptr;
    cppResult = cppSelf | cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___xor__(PyObject *self, PyObject *pyArg)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyLong_AsLong(pyArg)));
    if (PyErr_Occurred())
    return nullptr;
#else
    cppSelf = static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QtDataVisualization::QSurface3DSeries::DrawFlags>(int(PyInt_AsLong(pyArg)));
#endif

    if (PyErr_Occurred())
        return nullptr;
    cppResult = cppSelf ^ cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___invert__(PyObject *self, PyObject *pyArg)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags cppSelf;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, self, &cppSelf);
    ::QtDataVisualization::QSurface3DSeries::DrawFlags cppResult = ~cppSelf;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, &cppResult);
}

static PyObject *SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_long(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, self, &val);
    return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &val);
}
static int SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag__nonzero(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])->converter, self, &val);
    return val != 0;
}

static PyType_Slot SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_number_slots[] = {
#ifdef IS_PY3K
    {Py_nb_bool,    reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag__nonzero)},
#else
    {Py_nb_nonzero, reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag__nonzero)},
    {Py_nb_long,    reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_long)},
#endif
    {Py_nb_invert,  reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___invert__)},
    {Py_nb_and,     reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___and__)},
    {Py_nb_xor,     reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___xor__)},
    {Py_nb_or,      reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag___or__)},
    {Py_nb_int,     reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_long)},
    {Py_nb_index,   reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_long)},
#ifndef IS_PY3K
    {Py_nb_long,    reinterpret_cast<void *>(SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_long)},
#endif
    {0, nullptr} // sentinel
};



// Type conversion functions.

// Python to C++ enum conversion.
static void QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QtDataVisualization_QSurface3DSeries_DrawFlag(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QtDataVisualization::QSurface3DSeries::DrawFlag *>(cppOut) =
        static_cast<::QtDataVisualization::QSurface3DSeries::DrawFlag>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QtDataVisualization_QSurface3DSeries_DrawFlag_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX]))
        return QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QtDataVisualization_QSurface3DSeries_DrawFlag;
    return {};
}
static PyObject *QtDataVisualization_QSurface3DSeries_DrawFlag_CppToPython_QtDataVisualization_QSurface3DSeries_DrawFlag(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QtDataVisualization::QSurface3DSeries::DrawFlag *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX], castCppIn);

}

static void QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag> *>(cppOut) =
        ::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>(QFlag(int(PySide::QFlags::getValue(reinterpret_cast<PySideQFlagsObject *>(pyIn)))));

}
static PythonToCppFunc is_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX]))
        return QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_;
    return {};
}
static PyObject *QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__CppToPython_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag> *>(cppIn));
    return reinterpret_cast<PyObject *>(PySide::QFlags::newObject(castCppIn, SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX]));

}

static void QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag> *>(cppOut) =
        ::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>(QFlag(int(Shiboken::Enum::getValue(pyIn))));

}
static PythonToCppFunc is_QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX]))
        return QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_;
    return {};
}
static void number_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_(PyObject *pyIn, void *cppOut) {
    Shiboken::AutoDecRef pyLong(PyNumber_Long(pyIn));
    *reinterpret_cast<::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag> *>(cppOut) =
        ::QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>(QFlag(int(PyLong_AsLong(pyLong.object()))));

}
static PythonToCppFunc is_number_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__Convertible(PyObject *pyIn) {
    if (PyNumber_Check(pyIn) && PyObject_TypeCheck(pyIn, SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX]))
        return number_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_;
    return {};
}
// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QtDataVisualization_QSurface3DSeries_TypeF())))
        return QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSurface3DSeries_PTR_CppToPython_QSurface3DSeries(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::QtDataVisualization::QSurface3DSeries *>(const_cast<void *>(cppIn)), Sbk_QtDataVisualization_QSurface3DSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QtDataVisualization_QSurface3DSeries_SignatureStrings[] = {
    "1:PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries(self,parent:PySide2.QtCore.QObject=nullptr)",
    "0:PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries(self,dataProxy:PySide2.QtDataVisualization.QtDataVisualization.QSurfaceDataProxy,parent:PySide2.QtCore.QObject=nullptr)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.dataProxy(self)->PySide2.QtDataVisualization.QtDataVisualization.QSurfaceDataProxy",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.drawMode(self)->PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.DrawFlags",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.invalidSelectionPosition()->PySide2.QtCore.QPoint",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.isFlatShadingEnabled(self)->bool",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.isFlatShadingSupported(self)->bool",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.selectedPoint(self)->PySide2.QtCore.QPoint",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setDataProxy(self,proxy:PySide2.QtDataVisualization.QtDataVisualization.QSurfaceDataProxy)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setDrawMode(self,mode:PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.DrawFlags)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setFlatShadingEnabled(self,enabled:bool)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setSelectedPoint(self,position:PySide2.QtCore.QPoint)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setTexture(self,texture:PySide2.QtGui.QImage)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.setTextureFile(self,filename:QString)",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.texture(self)->PySide2.QtGui.QImage",
    "PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.textureFile(self)->QString",
    nullptr}; // Sentinel

void init_QtDataVisualization_QSurface3DSeries(PyObject *enclosingClass)
{
    _Sbk_QtDataVisualization_QSurface3DSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QSurface3DSeries",
        "QtDataVisualization::QSurface3DSeries*",
        &Sbk_QtDataVisualization_QSurface3DSeries_spec,
        &Shiboken::callCppDestructor< ::QtDataVisualization::QSurface3DSeries >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QABSTRACT3DSERIES_IDX]),
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass    );
    
    auto pyType = reinterpret_cast<PyTypeObject *>(_Sbk_QtDataVisualization_QSurface3DSeries_Type);
    InitSignatureStrings(pyType, QtDataVisualization_QSurface3DSeries_SignatureStrings);
    SbkObjectType_SetPropertyStrings(reinterpret_cast<PyTypeObject *>(_Sbk_QtDataVisualization_QSurface3DSeries_Type), Sbk_QtDataVisualization_QSurface3DSeries_PropertyStrings);
    SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QtDataVisualization_QSurface3DSeries_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(),
        QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR,
        is_QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR_Convertible,
        QSurface3DSeries_PTR_CppToPython_QSurface3DSeries);

    Shiboken::Conversions::registerConverterName(converter, "QtDataVisualization::QSurface3DSeries");
    Shiboken::Conversions::registerConverterName(converter, "QtDataVisualization::QSurface3DSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QtDataVisualization::QSurface3DSeries&");
    Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries");
    Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtDataVisualization::QSurface3DSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSurface3DSeriesWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), &Sbk_QtDataVisualization_QSurface3DSeries_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'DrawFlag'.
    SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX] = PySide::QFlags::create("2:PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.DrawFlags", SbkPySide2_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlag_number_slots);
    SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(),
        "DrawFlag",
        "2:PySide2.QtDataVisualization.QtDataVisualization.QSurface3DSeries.DrawFlag",
        "QtDataVisualization::QSurface3DSeries::DrawFlag",
        SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX]);
    if (!SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX],
        Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), "DrawWireframe", (long) QtDataVisualization::QSurface3DSeries::DrawFlag::DrawWireframe))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX],
        Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), "DrawSurface", (long) QtDataVisualization::QSurface3DSeries::DrawFlag::DrawSurface))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX],
        Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), "DrawSurfaceAndWireframe", (long) QtDataVisualization::QSurface3DSeries::DrawFlag::DrawSurfaceAndWireframe))
        return;
    // Register converter for enum 'QtDataVisualization::QSurface3DSeries::DrawFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX],
            QtDataVisualization_QSurface3DSeries_DrawFlag_CppToPython_QtDataVisualization_QSurface3DSeries_DrawFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QtDataVisualization_QSurface3DSeries_DrawFlag,
            is_QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QtDataVisualization_QSurface3DSeries_DrawFlag_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtDataVisualizationTypes[SBK_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QtDataVisualization::QSurface3DSeries::DrawFlag");
        Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries::DrawFlag");
        Shiboken::Conversions::registerConverterName(converter, "DrawFlag");
    }
    // Register converter for flag 'QFlags<QtDataVisualization::QSurface3DSeries::DrawFlag>'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX],
            QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__CppToPython_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_,
            is_QtDataVisualization_QSurface3DSeries_DrawFlag_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_,
            is_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            number_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag_,
            is_number_PythonToCpp_QFlags_QtDataVisualization_QSurface3DSeries_DrawFlag__Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtDataVisualizationTypes[SBK_QFLAGS_QTDATAVISUALIZATION_QSURFACE3DSERIES_DRAWFLAG_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QtDataVisualization::QSurface3DSeries::DrawFlags");
        Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries::DrawFlags");
        Shiboken::Conversions::registerConverterName(converter, "DrawFlags");
    }
    // End of 'DrawFlag' enum/flags.

    PySide::Signal::registerSignals(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), &::QtDataVisualization::QSurface3DSeries::staticMetaObject);
    qRegisterMetaType< ::QtDataVisualization::QSurface3DSeries::DrawFlag >("QSurface3DSeries::DrawFlag");
    qRegisterMetaType< ::QtDataVisualization::QSurface3DSeries::DrawFlag >("QtDataVisualization::QSurface3DSeries::DrawFlag");
    qRegisterMetaType< ::QtDataVisualization::QSurface3DSeries::DrawFlags >("QtDataVisualization::QSurface3DSeries::DrawFlags");
    Shiboken::ObjectType::setSubTypeInitHook(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_QtDataVisualization_QSurface3DSeries_TypeF(), &::QtDataVisualization::QSurface3DSeries::staticMetaObject, sizeof(QSurface3DSeriesWrapper));
}
